@@ -31,6 +31,12 @@ is.extmat <- function(X) {
   .Call("is_extmat", X)
 }
 
+ematmul <- function(emat, v, transposed = FALSE) {
+  storage.mode(v) <- "double";
+  storage.mode(transposed) <- "logical";
+  .Call("ematmul", emat, v, transposed);
+}
+
 extmat <- function(mul, tmul, nrow, ncol,
                    env = .GlobalEnv) {
   .Call("initialize_extmat",
